Address class

Constructors

Address({required List<AddressComponent> addressComponents, required String formattedAddress, required Geometry geometry, required String placeId, required List<String> types})
const
Address.fromMap(Map<String, dynamic> map)
factory

Properties

addressComponents → List<AddressComponent>
final
formattedAddress → String
final
geometry → Geometry
final
hashCode → int
The hash code for this object.
no setterinherited
placeId → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
types → List<String>
final

Methods

getSimpleAddress() → SimpleAddress
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited