GeocodeResponse class

Constructors

GeocodeResponse.fromError(String errorMessage)
factory
GeocodeResponse.fromMap(Map<String, dynamic> map)
factory

Properties

errorMessage → String?
final
hashCode → int
The hash code for this object.
no setterinherited
isSuccess → bool
no setter
results → List<Address>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → ResponseStatus
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited