SimpleAddress class

Constructors

SimpleAddress({String? streetNumber, String? route, String? subLocality, String? locality, String? administrativeAreaLevel3, String? administrativeAreaLevel2, String? administrativeAreaLevel1, String? country, String? postalCode, required LatLngLiteral location, required String formattedAddress})

Properties

administrativeAreaLevel1 → String?
final
administrativeAreaLevel2 → String?
final
administrativeAreaLevel3 → String?
final
city → String?
no setter
country → String?
final
formattedAddress → String
final
hashCode → int
The hash code for this object.
no setterinherited
locality → String?
final
location → LatLngLiteral
final
postalCode → String?
final
province → String?
no setter
route → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
streetNumber → String?
final
subLocality → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited