Geocoder class

Inheritance

Constructors

Geocoder({String? apiKey, bool debug = false})

Properties

apiKey → String?
no setterinherited
debug → bool
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
language → String
no setterinherited
locationType → String?
no setter
region → String?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
inherited
doGet({required String path, required Map<String, dynamic> params}) → Future
inherited
fromAddress(String address, {String? apiKey, String? language, String? region, String? locationType}) → Future<GeocodeResponse>
fromLatLng(double latitude, double longitude, {String? apiKey, String? language, String? region, String? locationType}) → Future<GeocodeResponse>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setApiKey(String key) → void
inherited
setLanguage(String language) → void
inherited
setLocationType(String type) → void
setRegion(String region) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited